﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Media.Imaging;
using System.Collections.ObjectModel;

namespace WebCamAudioDemo
{
    public partial class MainPage : UserControl
    {
        CaptureSource _captureSource;
        ObservableCollection<WriteableBitmap> _pictures = new ObservableCollection<WriteableBitmap>();

        public MainPage()
        {
            InitializeComponent();
            this.Loaded += new RoutedEventHandler(MainPage_Loaded);
        }

        void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            // creating a new capture source
            _captureSource = new CaptureSource();

            // get list of the web cams
            WebCamList.ItemsSource = CaptureDeviceConfiguration.GetAvailableVideoCaptureDevices();
            WebCamList.SelectedIndex = 0;

            // get list of microphones
            MicrophoneList.ItemsSource = CaptureDeviceConfiguration.GetAvailableAudioCaptureDevices();
            MicrophoneList.SelectedIndex = 0;

            Pictures.ItemsSource = _pictures;
        }

        private void btnStartCapture_Click(object sender, RoutedEventArgs e)
        {
            if (_captureSource != null)
            {
                // stop whatever device may be capturing
                _captureSource.Stop();

                _captureSource.VideoCaptureDevice = (VideoCaptureDevice)WebCamList.SelectedItem;
                _captureSource.AudioCaptureDevice = (AudioCaptureDevice)MicrophoneList.SelectedItem;

                VideoBrush vidBrush = new VideoBrush();
                vidBrush.SetSource(_captureSource);
                ViewBox.Fill = vidBrush;

                // request access to webcam and audio devices
                if (CaptureDeviceConfiguration.AllowedDeviceAccess || CaptureDeviceConfiguration.RequestDeviceAccess())
                {
                    _captureSource.Start();
                }
            }
        }

        private void btnStopCapture_Click(object sender, RoutedEventArgs e)
        {
            if (_captureSource != null)
            {
                _captureSource.Stop();
            }
        }

        private void btnTakePicture_Click(object sender, RoutedEventArgs e)
        {
            if (_captureSource != null)
            {
                _captureSource.AsyncCaptureImage((image) =>
                {
                    _pictures.Add(image);
                });
            }
        }
    }
}
